#ifndef NT2_INCLUDE_FUNCTIONS_GAMCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GAMCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/gamcdf.hpp>

#endif
